@@ -142,7 +142,7 @@ yourlabs.TextWidget.prototype.selectChoice = function(choice) {
 
 // Return the value of an HTML choice, used to fill the input.
 yourlabs.TextWidget.prototype.getValue = function(choice) {
-    return choice.html();
+    return $.trim(choice.html().replace(/(<([^>]+)>)/ig,""));
 }
 
 // Initialize the widget.
@@ -222,11 +222,12 @@ $.fn.yourlabsTextWidget = function(overrides) {
 }
 
 $(document).ready(function() {
-    $('body').on('initialize', 'input[data-bootstrap=normal]', function() {
+    $('body').on('initialize', 'input[data-widget-bootstrap=text]', function() {
         /*
-        Only setup autocompletes on inputs which have data-bootstrap=normal,
-        if you want to initialize some autocompletes with custom code, then set
-        data-boostrap=yourbootstrap or something like that.
+        Only setup autocompletes on inputs which have
+        data-widget-bootstrap=text, if you want to initialize some
+        autocompletes with custom code, then set
+        data-widget-boostrap=yourbootstrap or something like that.
         */
         $(this).yourlabsTextWidget();
     });
@@ -234,7 +235,7 @@ $(document).ready(function() {
     // Solid initialization, usage::
     //
     //      $(document).bind('yourlabsTextWidgetReady', function() {
-    //          $('body').on('initialize', 'input[data-bootstrap=normal]', function() {
+    //          $('body').on('initialize', 'input[data-widget-bootstrap=text]', function() {
     //              $(this).yourlabsTextWidget({
     //                  yourCustomArgs: // ...
     //              })
